@@ -2,6 +2,8 @@
 $description Global live-streaming platform owned by BitTorrent, Inc.
 $url dlive.tv
 $type live, vod
+$metadata author
+$metadata title
 """
 
 import logging
@@ -12,6 +14,7 @@ from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
 from streamlink.stream.hls import HLSStream
 
+
 log = logging.getLogger(__name__)
 
 
